powered by
This is the main function to recreate a previous generated image. It takes all relevant information from the log file to get exactly the same result. By using the same formula and the same seed you get the same randon numbers.
regenerate_img(seed_to_recreate, filetype, polar = FALSE)
the seed of the original image that either put in as a numeric value or vector from "get_seed_from_logfile()"
set the file type for the image
logical should the plot have a polar coordinate system ("polar = TRUE") or a cartesian coordinate system ("polar = FALSE")
an image as png
get_formula_from_logfile get the formula for recreation
get_formula_from_logfile
get_seed_from_logfile get the seed, which is used as input
get_seed_from_logfile
# NOT RUN { regenerate_img(0104, polar = FALSE) # }
Run the code above in your browser using DataLab